@@ -15,6 +15,8 @@ THING_ID = os.getenv("THING_ID", None)
 PRIVATE_KEY_PATH = os.getenv("PRIVATE_KEY_PATH", None)
 HTTP_API_URI = os.getenv(
     "HTTP_API_URI", "https://dwd.tudelft.nl:443/bucket/api")
+TOKEN_ALGO = os.getenv(
+    "TOKEN_ALGO", "RS256")
 
 DIGI_CERT_CA = os.getenv("DIGI_CERT_CA", "DigiCertCA.crt")
 
@@ -45,6 +47,7 @@ class Thing:
     def __init__(self,
                  thing_id: str = None,
                  private_key_path: str = None,
+                 private_key: str = None,
                  json_thing: dict = None,
                  connect = True):
         """
@@ -91,7 +94,7 @@ class Thing:
             # If there is a thing id, try to connect
             if self.thing_id is not None:
                 self.token = ThingToken(
-                    private_key_path, self.thing_id, HTTP_API_URI, HTTP_API_URI)
+                    private_key_path, self.thing_id, HTTP_API_URI, HTTP_API_URI, algorithm=TOKEN_ALGO)
                 self.http = ThingHTTP(self, HTTP_API_URI)
 
                 # Loads all thing's details
